@@ -15,8 +15,8 @@
  *                                                                         *
  *   You should have received a copy of the GNU Lesser General Public      *
  *   License along with this library; if not, write to the Free Software   *
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  *
- *   USA                                                                   *
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
+ *   02110-1301  USA                                                       *
  *                                                                         *
  *   Alternatively, this file is available under the Mozilla Public        *
  *   License Version 1.1.  You may obtain a copy of the License at         *
@@ -146,14 +146,16 @@ public:
   ByteVector render(ASF::File *file);
 };
 
-void
-ASF::File::BaseObject::parse(ASF::File *file, unsigned int size)
+void ASF::File::BaseObject::parse(ASF::File *file, unsigned int size)
 {
-  data = file->readBlock(size - 24);
+  data.clear();
+  if (size > 24 && size <= (unsigned int)(file->length()))
+    data = file->readBlock(size - 24);
+  else
+    data = ByteVector::null;
 }
 
-ByteVector
-ASF::File::BaseObject::render(ASF::File * /*file*/)
+ByteVector ASF::File::BaseObject::render(ASF::File * /*file*/)
 {
   return guid() + ByteVector::fromLongLong(data.size() + 24, false) + data;
 }
@@ -162,33 +164,28 @@ ASF::File::UnknownObject::UnknownObject(const ByteVector &guid) : myGuid(guid)
 {
 }
 
-ByteVector
-ASF::File::UnknownObject::guid()
+ByteVector ASF::File::UnknownObject::guid()
 {
   return myGuid;
 }
 
-ByteVector
-ASF::File::FilePropertiesObject::guid()
+ByteVector ASF::File::FilePropertiesObject::guid()
 {
   return filePropertiesGuid;
 }
 
-void
-ASF::File::FilePropertiesObject::parse(ASF::File *file, uint size)
+void ASF::File::FilePropertiesObject::parse(ASF::File *file, uint size)
 {
   BaseObject::parse(file, size);
   file->d->properties->setLength((int)(data.mid(40, 8).toLongLong(false) / 10000000L - data.mid(56, 8).toLongLong(false) / 1000L));
 }
 
-ByteVector
-ASF::File::StreamPropertiesObject::guid()
+ByteVector ASF::File::StreamPropertiesObject::guid()
 {
   return streamPropertiesGuid;
 }
 
-void
-ASF::File::StreamPropertiesObject::parse(ASF::File *file, uint size)
+void ASF::File::StreamPropertiesObject::parse(ASF::File *file, uint size)
 {
   BaseObject::parse(file, size);
   file->d->properties->setChannels(data.mid(56, 2).toShort(false));
@@ -196,14 +193,12 @@ ASF::File::StreamPropertiesObject::parse(ASF::File *file, uint size)
   file->d->properties->setBitrate(data.mid(62, 4).toUInt(false) * 8 / 1000);
 }
 
-ByteVector
-ASF::File::ContentDescriptionObject::guid()
+ByteVector ASF::File::ContentDescriptionObject::guid()
 {
   return contentDescriptionGuid;
 }
 
-void
-ASF::File::ContentDescriptionObject::parse(ASF::File *file, uint /*size*/)
+void ASF::File::ContentDescriptionObject::parse(ASF::File *file, uint /*size*/)
 {
   file->d->contentDescriptionObject = this;
   int titleLength = file->readWORD();
@@ -218,8 +213,7 @@ ASF::File::ContentDescriptionObject::parse(ASF::File *file, uint /*size*/)
   file->d->tag->setRating(file->readString(ratingLength));
 }
 
-ByteVector
-ASF::File::ContentDescriptionObject::render(ASF::File *file)
+ByteVector ASF::File::ContentDescriptionObject::render(ASF::File *file)
 {
   ByteVector v1 = file->renderString(file->d->tag->title());
   ByteVector v2 = file->renderString(file->d->tag->artist());
@@ -240,14 +234,12 @@ ASF::File::ContentDescriptionObject::render(ASF::File *file)
   return BaseObject::render(file);
 }
 
-ByteVector
-ASF::File::ExtendedContentDescriptionObject::guid()
+ByteVector ASF::File::ExtendedContentDescriptionObject::guid()
 {
   return extendedContentDescriptionGuid;
 }
 
-void
-ASF::File::ExtendedContentDescriptionObject::parse(ASF::File *file, uint /*size*/)
+void ASF::File::ExtendedContentDescriptionObject::parse(ASF::File *file, uint /*size*/)
 {
   file->d->extendedContentDescriptionObject = this;
   int count = file->readWORD();
@@ -258,8 +250,7 @@ ASF::File::ExtendedContentDescriptionObject::parse(ASF::File *file, uint /*size*
   }
 }
 
-ByteVector
-ASF::File::ExtendedContentDescriptionObject::render(ASF::File *file)
+ByteVector ASF::File::ExtendedContentDescriptionObject::render(ASF::File *file)
 {
   data.clear();
   data.append(ByteVector::fromShort(attributeData.size(), false));
@@ -267,14 +258,12 @@ ASF::File::ExtendedContentDescriptionObject::render(ASF::File *file)
   return BaseObject::render(file);
 }
 
-ByteVector
-ASF::File::MetadataObject::guid()
+ByteVector ASF::File::MetadataObject::guid()
 {
   return metadataGuid;
 }
 
-void
-ASF::File::MetadataObject::parse(ASF::File *file, uint /*size*/)
+void ASF::File::MetadataObject::parse(ASF::File *file, uint /*size*/)
 {
   file->d->metadataObject = this;
   int count = file->readWORD();
@@ -285,8 +274,7 @@ ASF::File::MetadataObject::parse(ASF::File *file, uint /*size*/)
   }
 }
 
-ByteVector
-ASF::File::MetadataObject::render(ASF::File *file)
+ByteVector ASF::File::MetadataObject::render(ASF::File *file)
 {
   data.clear();
   data.append(ByteVector::fromShort(attributeData.size(), false));
@@ -294,14 +282,12 @@ ASF::File::MetadataObject::render(ASF::File *file)
   return BaseObject::render(file);
 }
 
-ByteVector
-ASF::File::MetadataLibraryObject::guid()
+ByteVector ASF::File::MetadataLibraryObject::guid()
 {
   return metadataLibraryGuid;
 }
 
-void
-ASF::File::MetadataLibraryObject::parse(ASF::File *file, uint /*size*/)
+void ASF::File::MetadataLibraryObject::parse(ASF::File *file, uint /*size*/)
 {
   file->d->metadataLibraryObject = this;
   int count = file->readWORD();
@@ -312,8 +298,7 @@ ASF::File::MetadataLibraryObject::parse(ASF::File *file, uint /*size*/)
   }
 }
 
-ByteVector
-ASF::File::MetadataLibraryObject::render(ASF::File *file)
+ByteVector ASF::File::MetadataLibraryObject::render(ASF::File *file)
 {
   data.clear();
   data.append(ByteVector::fromShort(attributeData.size(), false));
@@ -321,14 +306,12 @@ ASF::File::MetadataLibraryObject::render(ASF::File *file)
   return BaseObject::render(file);
 }
 
-ByteVector
-ASF::File::HeaderExtensionObject::guid()
+ByteVector ASF::File::HeaderExtensionObject::guid()
 {
   return headerExtensionGuid;
 }
 
-void
-ASF::File::HeaderExtensionObject::parse(ASF::File *file, uint /*size*/)
+void ASF::File::HeaderExtensionObject::parse(ASF::File *file, uint /*size*/)
 {
   file->d->headerExtensionObject = this;
   file->seek(18, File::Current);
@@ -353,8 +336,7 @@ ASF::File::HeaderExtensionObject::parse(ASF::File *file, uint /*size*/)
   }
 }
 
-ByteVector
-ASF::File::HeaderExtensionObject::render(ASF::File *file)
+ByteVector ASF::File::HeaderExtensionObject::render(ASF::File *file)
 {
   data.clear();
   for(unsigned int i = 0; i < objects.size(); i++) {
@@ -518,7 +500,7 @@ int ASF::File::readBYTE()
 int ASF::File::readWORD()
 {
   ByteVector v = readBlock(2);
-  return v.toShort(false);
+  return v.toUShort(false);
 }
 
 unsigned int ASF::File::readDWORD()
@@ -533,8 +515,7 @@ long long ASF::File::readQWORD()
   return v.toLongLong(false);
 }
 
-String
-ASF::File::readString(int length)
+String ASF::File::readString(int length)
 {
   ByteVector data = readBlock(length);
   unsigned int size = data.size();
@@ -550,8 +531,7 @@ ASF::File::readString(int length)
   return String(data, String::UTF16LE);
 }
 
-ByteVector
-ASF::File::renderString(const String &str, bool includeLength)
+ByteVector ASF::File::renderString(const String &str, bool includeLength)
 {
   ByteVector data = str.data(String::UTF16LE) + ByteVector::fromShort(0, false);
   if(includeLength) {
