@@ -15,8 +15,8 @@
  *                                                                         *
  *   You should have received a copy of the GNU Lesser General Public      *
  *   License along with this library; if not, write to the Free Software   *
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  *
- *   USA                                                                   *
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
+ *   02110-1301  USA                                                       *
  *                                                                         *
  *   Alternatively, this file is available under the Mozilla Public        *
  *   License Version 1.1.  You may obtain a copy of the License at         *
@@ -56,54 +56,46 @@ ASF::Tag::~Tag()
     delete d;
 }
 
-String
-ASF::Tag::title() const
+String ASF::Tag::title() const
 {
   return d->title;
 }
 
-String
-ASF::Tag::artist() const
+String ASF::Tag::artist() const
 {
   return d->artist;
 }
 
-String
-ASF::Tag::album() const
+String ASF::Tag::album() const
 {
   if(d->attributeListMap.contains("WM/AlbumTitle"))
     return d->attributeListMap["WM/AlbumTitle"][0].toString();
   return String::null;
 }
 
-String
-ASF::Tag::copyright() const
+String ASF::Tag::copyright() const
 {
   return d->copyright;
 }
 
-String
-ASF::Tag::comment() const
+String ASF::Tag::comment() const
 {
   return d->comment;
 }
 
-String
-ASF::Tag::rating() const
+String ASF::Tag::rating() const
 {
   return d->rating;
 }
 
-unsigned int
-ASF::Tag::year() const
+unsigned int ASF::Tag::year() const
 {
   if(d->attributeListMap.contains("WM/Year"))
     return d->attributeListMap["WM/Year"][0].toString().toInt();
   return 0;
 }
 
-unsigned int
-ASF::Tag::track() const
+unsigned int ASF::Tag::track() const
 {
   if(d->attributeListMap.contains("WM/TrackNumber")) {
     const ASF::Attribute attr = d->attributeListMap["WM/TrackNumber"][0];
@@ -117,70 +109,59 @@ ASF::Tag::track() const
   return 0;
 }
 
-String
-ASF::Tag::genre() const
+String ASF::Tag::genre() const
 {
   if(d->attributeListMap.contains("WM/Genre"))
     return d->attributeListMap["WM/Genre"][0].toString();
   return String::null;
 }
 
-void
-ASF::Tag::setTitle(const String &value)
+void ASF::Tag::setTitle(const String &value)
 {
   d->title = value;
 }
 
-void
-ASF::Tag::setArtist(const String &value)
+void ASF::Tag::setArtist(const String &value)
 {
   d->artist = value;
 }
 
-void
-ASF::Tag::setCopyright(const String &value)
+void ASF::Tag::setCopyright(const String &value)
 {
   d->copyright = value;
 }
 
-void
-ASF::Tag::setComment(const String &value)
+void ASF::Tag::setComment(const String &value)
 {
   d->comment = value;
 }
 
-void
-ASF::Tag::setRating(const String &value)
+void ASF::Tag::setRating(const String &value)
 {
   d->rating = value;
 }
 
-void
-ASF::Tag::setAlbum(const String &value)
+void ASF::Tag::setAlbum(const String &value)
 {
   setAttribute("WM/AlbumTitle", value);
 }
 
-void
-ASF::Tag::setGenre(const String &value)
+void ASF::Tag::setGenre(const String &value)
 {
   setAttribute("WM/Genre", value);
 }
 
-void
-ASF::Tag::setYear(uint value)
+void ASF::Tag::setYear(uint value)
 {
   setAttribute("WM/Year", String::number(value));
 }
 
-void
-ASF::Tag::setTrack(uint value)
+void ASF::Tag::setTrack(uint value)
 {
   setAttribute("WM/TrackNumber", String::number(value));
 }
 
-ASF::AttributeListMap&
-ASF::Tag::attributeListMap()
+ASF::AttributeListMap& ASF::Tag::attributeListMap()
 {
   return d->attributeListMap;
 }
@@ -209,7 +190,8 @@ void ASF::Tag::addAttribute(const String &name, const Attribute &attribute)
   }
 }
 
-bool ASF::Tag::isEmpty() const {
+bool ASF::Tag::isEmpty() const
+{
   return TagLib::Tag::isEmpty() &&
          copyright().isEmpty() &&
          rating().isEmpty() &&
